@@ -1,4 +1,5 @@
 import sys
+import importlib
 import unittest
 import subprocess
 import time
@@ -61,6 +62,14 @@ def clean_text_foo(row):
     return text
 
 
+def run_if_modin_installed(cls):
+    # if modin is installed, run the test/test suite
+    if importlib.util.find_spec("modin") is not None:
+        return cls
+    else:  # if modin isnt installed just skip the test(s)
+        return True
+
+
 class TestSwifter(unittest.TestCase):
     def assertSeriesEqual(self, a, b, msg):
         try:
@@ -142,11 +151,11 @@ class TestSetup(TestSwifter):
                     {"x": np.arange(0, 10)}, index=pd.date_range("2019-01-1", "2020-01-1", periods=10)
                 ).swifter.resample("3T"),
             ],
-            [0.5, 0.99, 52428800],
+            [0.5, 0.99, 100000000],
             [
                 ceil(virtual_memory().available * 0.5),
                 ceil(virtual_memory().available * 0.99),
-                52428800,
+                100000000,
             ],
         ):
             before = swifter_df._ray_memory
@@ -450,8 +459,10 @@ class TestPandasDataFrame(TestSwifter):
         if self.ncores > 1:  # speed test
             self.assertLess(swifter_time, pd_time)
 
+    @run_if_modin_installed
     def test_nonvectorized_text_modin_apply_on_large_dataframe(self):
         LOG.info("test_nonvectorized_text_modin_apply_on_large_dataframe")
+        self.modinSetUp()
         df = pd.DataFrame({"letter": ["I", "You", "We"] * 1_000_000, "value": ["want to break free"] * 3_000_000})
 
         tqdm.pandas(desc="Pandas Nonvec text apply ~ DF")
@@ -475,8 +486,10 @@ class TestPandasDataFrame(TestSwifter):
         if self.ncores > 1:  # speed test
             self.assertLess(swifter_time, pd_time)
 
+    @run_if_modin_installed
     def test_nonvectorized_text_modin_apply_on_large_dataframe_returns_series(self):
         LOG.info("test_nonvectorized_text_modin_apply_on_large_dataframe_returns_series")
+        self.modinSetUp()
         df = pd.DataFrame({"str_date": ["2000/01/01 00:00:00"] * 1_000_000})
 
         tqdm.pandas(desc="Pandas Nonvec text apply ~ DF -> Srs")
@@ -596,25 +609,14 @@ class TestPandasTransformation(TestSwifter):
         df = pd.DataFrame(
             {"x": np.arange(0, 1_000_000)}, index=pd.date_range("2019-01-1", "2020-01-1", periods=1_000_000)
         )
-
-        start_pd = time.time()
         pd_val = df.rolling("1d").apply(max, raw=True)
-        end_pd = time.time()
-        pd_time = end_pd - start_pd
-
-        start_swifter = time.time()
         swifter_val = (
             df.swifter.set_npartitions(4)
             .rolling("1d")
             .progress_bar(desc="Vec math apply ~ Rolling DF")
             .apply(max, raw=True)
         )
-        end_swifter = time.time()
-        swifter_time = end_swifter - start_swifter
-
         self.assertEqual(pd_val, swifter_val)  # equality test
-        if self.ncores > 1:  # speed test
-            self.assertLess(swifter_time, pd_time)
 
     def test_nonvectorized_math_apply_on_large_rolling_dataframe(self):
         LOG.info("test_nonvectorized_math_apply_on_large_rolling_dataframe")
@@ -679,6 +681,7 @@ class TestPandasTransformation(TestSwifter):
             self.assertLess(swifter_time, pd_time)
 
 
+@run_if_modin_installed
 class TestModinSeries(TestSwifter):
     def test_modin_series_warns_on_missing_attributes(self):
         LOG.info("test_modin_series_warns_on_missing_attributes")
@@ -753,6 +756,7 @@ class TestModinSeries(TestSwifter):
         self.assertLess(swifter_time, md_time)  # speed test
 
 
+@run_if_modin_installed
 class TestModinDataFrame(TestSwifter):
     def test_modin_dataframe_warns_on_missing_attributes(self):
         LOG.info("test_modin_dataframe_warns_on_missing_attributes")
